.. include:: ../README.rst



.. toctree::
   :maxdepth: 1

   usage
   queue
   api


.. toctree::
   :maxdepth: 2

   changelog

Development
===========

zope.sendmail is hosted at GitHub:

    https://github.com/zopefoundation/zope.sendmail/



Project URLs
============

* https://pypi.python.org/pypi/zope.sendmail       (PyPI entry and downloads)


====================
 Indices and tables
====================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
